@@ -26,6 +26,7 @@
 #include <stdlib.h>
 #include <glib.h>
 #include <glib-object.h>
+#include <gdesktop-enums.h>
 #include <discid/discid.h>
 #include <musicbrainz5/mb5_c.h>
 
@@ -57,6 +58,7 @@ typedef struct {
   char    *cdrom;
   GHashTable *artist_cache;
   /* Proxy */
+  GDesktopProxyMode proxy_mode;
   char    *proxy_host;
   char    *proxy_username;
   char    *proxy_password;
@@ -74,7 +76,8 @@ enum {
   PROP_PROXY_HOST,
   PROP_PROXY_PORT,
   PROP_PROXY_USERNAME,
-  PROP_PROXY_PASSWORD
+  PROP_PROXY_PASSWORD,
+  PROP_PROXY_MODE
 };
 
 static void metadata_interface_init (gpointer g_iface, gpointer iface_data);
@@ -309,6 +312,7 @@ get_release_labels (Mb5Release *release)
   int i;
   char buffer[512]; /* for the GET() macro */
   GList *label_list = NULL;
+  GList *it = NULL;
 
   list = mb5_release_get_labelinfolist (release);
   if (list == NULL)
@@ -327,10 +331,17 @@ get_release_labels (Mb5Release *release)
     if (label == NULL)
       continue;
 
+    mb5_label_get_name (label, buffer, sizeof (buffer));
+    for (it = label_list; it != NULL; it = it->next) {
+      if (strcmp (((LabelDetails*) it->data)->name, buffer) == 0)
+        goto skip;
+    }
     label_data = g_new0 (LabelDetails, 1);
-    GET (label_data->name,     mb5_label_get_name,     label);
+    label_data->name = g_strdup (buffer);
     GET (label_data->sortname, mb5_label_get_sortname, label);
     label_list = g_list_prepend (label_list, label_data);
+  skip:
+    ;
   }
   label_list = g_list_reverse (label_list);
   return label_list;
@@ -654,8 +665,10 @@ make_album_from_release (SjMetadataMusicbrainz5 *self,
                        &album->artist_id);
 
   GET (date, mb5_release_get_date, release);
-  album->release_date = sj_metadata_helper_scan_date (date);
-  g_free (date);
+  if (date) {
+    album->release_date = gst_date_time_new_from_iso8601_string (date);
+    g_free (date);
+  }
 
   GET (album->asin, mb5_release_get_asin, release);
   mb5_release_get_country (release, buffer, sizeof(buffer));
@@ -799,12 +812,16 @@ artist-rels";
 static void
 setup_http_proxy (SjMetadataMusicbrainz5Private *priv)
 {
-  if (priv->proxy_host == NULL || priv->proxy_port == 0) {
+  if (priv->proxy_mode == G_DESKTOP_PROXY_MODE_NONE ||
+      priv->proxy_mode == G_DESKTOP_PROXY_MODE_AUTO ||
+      priv->proxy_host == NULL || priv->proxy_port == 0) {
     mb5_query_set_proxyhost (priv->mb, NULL);
     mb5_query_set_proxyport (priv->mb, 0);
     mb5_query_set_proxyusername (priv->mb, NULL);
     mb5_query_set_proxypassword (priv->mb, NULL);
-  } else {
+    if (priv->proxy_mode == G_DESKTOP_PROXY_MODE_AUTO)
+      g_warning ("Automatic proxy mode not supported yet, disabling proxy usage");
+  } else if (priv->proxy_mode == G_DESKTOP_PROXY_MODE_MANUAL) {
     mb5_query_set_proxyhost (priv->mb, priv->proxy_host);
     mb5_query_set_proxyport (priv->mb, priv->proxy_port);
     if (priv->proxy_use_authentication &&
@@ -868,6 +885,9 @@ sj_metadata_musicbrainz5_get_property (GObject *object, guint property_id,
   case PROP_PROXY_PASSWORD:
     g_value_set_string (value, priv->proxy_password);
     break;
+  case PROP_PROXY_MODE:
+    g_value_set_enum (value, priv->proxy_mode);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -909,6 +929,10 @@ sj_metadata_musicbrainz5_set_property (GObject *object, guint property_id,
     priv->proxy_password = g_value_dup_string (value);
     setup_http_proxy (priv);
     break;
+  case PROP_PROXY_MODE:
+    priv->proxy_mode = g_value_get_enum (value);
+    setup_http_proxy (priv);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -962,6 +986,8 @@ sj_metadata_musicbrainz5_class_init (SjMetadataMusicbrainz5Class *class)
                                     PROP_PROXY_USERNAME, "proxy-username");
   g_object_class_override_property (object_class,
                                     PROP_PROXY_PASSWORD, "proxy-password");
+  g_object_class_override_property (object_class,
+                                    PROP_PROXY_MODE, "proxy-mode");
 
   /* Although GLib supports fallback locales we do not use them as
      MusicBrainz does not provide locale information for the canonical
