@@ -652,8 +652,8 @@ static void update_ui_for_album (AlbumDetails *album)
       gtk_entry_set_text (GTK_ENTRY (disc_number_entry), disc_number);
       g_free (disc_number);
     }
-    if (album->release_date && g_date_valid (album->release_date)) {
-      gchar *release_date =  g_strdup_printf ("%d", g_date_get_year (album->release_date));
+    if (album->release_date && gst_date_time_has_year (album->release_date)) {
+      gchar *release_date =  g_strdup_printf ("%d", gst_date_time_get_year (album->release_date));
       gtk_entry_set_text (GTK_ENTRY (year_entry), release_date);
       g_free (release_date);
     }
@@ -779,6 +779,51 @@ static gint collate (const char *a, const char *b)
   return ret_val;
 }
 
+static gint sj_gst_date_time_compare_field (GstDateTime *lhs, GstDateTime *rhs,
+                                            gboolean (*has_field) (const GstDateTime *datetime),
+                                            gint (*get_field) (const GstDateTime *datetime))
+{
+  gint field_lhs = -1;
+  gint field_rhs = -1;
+
+  if (has_field (lhs)) {
+    field_lhs = get_field (lhs);
+  }
+  if (has_field (rhs)) {
+    field_rhs = get_field (rhs);
+  }
+
+  return (field_lhs - field_rhs);
+}
+
+static gint sj_gst_date_time_compare (gpointer lhs, gpointer rhs)
+{
+  GstDateTime *date_lhs = (GstDateTime *)lhs;
+  GstDateTime *date_rhs = (GstDateTime *)rhs;
+
+  int comparison;
+
+  comparison = sj_gst_date_time_compare_field (date_lhs, date_rhs,
+                                               gst_date_time_has_year,
+                                               gst_date_time_get_year);
+  if (comparison != 0) {
+      return comparison;
+  }
+
+  comparison = sj_gst_date_time_compare_field (date_lhs, date_rhs,
+                                               gst_date_time_has_month,
+                                               gst_date_time_get_month);
+  if (comparison != 0) {
+      return comparison;
+  }
+
+  comparison = sj_gst_date_time_compare_field (date_lhs, date_rhs,
+                                               gst_date_time_has_day,
+                                               gst_date_time_get_day);
+
+  return comparison;
+}
+
 /**
  * Utility function to sort albums in multiple_album_dialog
  */
@@ -807,7 +852,7 @@ static gint sort_release_info (GtkTreeModel *model, GtkTreeIter *a,
 
   if (album_a->release_date) {
     if (album_b->release_date) {
-      ret_val = g_date_compare (album_a->release_date, album_b->release_date);
+      ret_val = sj_gst_date_time_compare (album_a->release_date, album_b->release_date);
       if (ret_val)
         return ret_val;
     } else {
@@ -867,6 +912,7 @@ static GString* format_label_text (GList* labels)
   if (count > 1) {
     g_string_append (label_text, ((LabelDetails*)labels->data)->name);
     g_string_append (label_text, " & ");
+    labels = labels->next;
   }
 
   g_string_append (label_text, ((LabelDetails*)labels->data)->name);
@@ -888,13 +934,13 @@ static char *format_release_details (AlbumDetails *album)
 
   if (!sj_str_is_empty (album->country)) {
     if (album->labels) {
-      if (album->release_date) {
+      if (album->release_date && gst_date_time_has_year (album->release_date)) {
         /* Translators: this string appears when multiple CDs were
          * found in musicbrainz online database, it corresponds to
          * "Released: <country> in <year> on <label>" */
         details = g_strdup_printf (_("Released: %s in %d on %s"),
                                    album->country,
-                                   g_date_get_year(album->release_date),
+                                   gst_date_time_get_year (album->release_date),
                                    label_text->str);
       } else {
         /* Translators: this string appears when multiple CDs were
@@ -902,32 +948,32 @@ static char *format_release_details (AlbumDetails *album)
          * "Released: <country> on <label>" */
         details = g_strdup_printf (_("Released: %s on %s"), album->country, label_text->str);
       }
-    } else if (album->release_date) {
+    } else if (album->release_date && gst_date_time_has_year (album->release_date)) {
       /* Translators: this string appears when multiple CDs were
        * found in musicbrainz online database, it corresponds to
        * "Released: <country> in <year>" */
       details = g_strdup_printf (_("Released: %s in %d"), album->country,
-                                 g_date_get_year (album->release_date));
+                                 gst_date_time_get_year (album->release_date));
     } else {
       /* Translators: this string appears when multiple CDs were
        * found in musicbrainz online database, it corresponds to
        * "Released: <country>" */
       details = g_strdup_printf (_("Released: %s"), album->country);
     }
-  } else if (album->release_date) {
+  } else if (album->release_date && gst_date_time_has_year (album->release_date)) {
     if (album->labels) {
         /* Translators: this string appears when multiple CDs were
          * found in musicbrainz online database, it corresponds to
          * "Released in <year> on <label>" */
         details = g_strdup_printf (_("Released in %d on %s"),
-                                   g_date_get_year(album->release_date),
+                                   gst_date_time_get_year (album->release_date),
                                    label_text->str);
     } else {
         /* Translators: this string appears when multiple CDs were
          * found in musicbrainz online database, it corresponds to
          * "Released in <year>" */
         details = g_strdup_printf(_("Released in %d"),
-                                  g_date_get_year(album->release_date));
+                                  gst_date_time_get_year (album->release_date));
     }
   } else if (album->labels) {
     /* Translators: this string appears when multiple CDs were
@@ -958,19 +1004,14 @@ AlbumDetails* multiple_album_dialog(GList *albums)
   GtkWidget *ok_button = NULL;
   enum COLUMNS
   {
-    COLUMN_TITLE,
-    COLUMN_ARTIST,
-    COLUMN_RELEASE_DETAILS,
+    COLUMN_RELEASE,
     COLUMN_DETAILS,
     COLUMN_COUNT
   };
 
   if (dialog == NULL) {
     GtkTreeViewColumn *column = gtk_tree_view_column_new ();
-    GtkCellArea *cell_area = gtk_cell_area_box_new ();
-    GtkCellRenderer *title_renderer  = gtk_cell_renderer_text_new ();
-    GtkCellRenderer *artist_renderer = gtk_cell_renderer_text_new ();
-    GtkCellRenderer *release_details_renderer   = gtk_cell_renderer_text_new ();
+    GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
 
     dialog = GET_WIDGET ("multiple_dialog");
     g_assert (dialog != NULL);
@@ -978,30 +1019,16 @@ AlbumDetails* multiple_album_dialog(GList *albums)
     albums_listview = GET_WIDGET ("albums_listview");
     ok_button       = GET_WIDGET ("ok_button");
 
-    g_object_get (G_OBJECT (column), "cell-area", &cell_area, NULL);
-    g_assert (cell_area != NULL);
-    gtk_orientable_set_orientation (GTK_ORIENTABLE (cell_area),
-                                    GTK_ORIENTATION_VERTICAL);
     gtk_tree_view_column_set_title (column, _("Albums"));
-    gtk_tree_view_column_pack_start (column, title_renderer,  TRUE);
-    gtk_tree_view_column_pack_start (column, artist_renderer, TRUE);
-    gtk_tree_view_column_pack_start (column, release_details_renderer,   TRUE);
-    g_object_set(title_renderer, "weight", PANGO_WEIGHT_BOLD, "weight-set",
-                 TRUE, NULL);
-    g_object_set(artist_renderer, "style", PANGO_STYLE_ITALIC, "style-set",
-                 TRUE, NULL);
-    gtk_tree_view_column_add_attribute (column, title_renderer,  "text",
-                                        COLUMN_TITLE);
-    gtk_tree_view_column_add_attribute (column, artist_renderer, "text",
-                                        COLUMN_ARTIST);
-    gtk_tree_view_column_add_attribute (column, release_details_renderer,   "text",
-                                        COLUMN_RELEASE_DETAILS);
+    gtk_tree_view_column_pack_start (column, renderer, TRUE);
+    gtk_tree_view_column_add_attribute (column, renderer,
+                                        "markup", COLUMN_RELEASE);
 
     g_signal_connect (albums_listview, "row-activated",
                       G_CALLBACK (album_row_activated), dialog);
 
-    albums_store = gtk_list_store_new (COLUMN_COUNT, G_TYPE_STRING,
-                                       G_TYPE_STRING, G_TYPE_STRING,
+    albums_store = gtk_list_store_new (COLUMN_COUNT,
+                                       G_TYPE_STRING,
                                        G_TYPE_POINTER);
     gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (albums_store),
                                      COLUMN_DETAILS, sort_release_info,
@@ -1023,19 +1050,22 @@ AlbumDetails* multiple_album_dialog(GList *albums)
     AlbumDetails *album = (AlbumDetails*)(albums->data);
     GString *album_title = g_string_new (album->title);
     gchar *release_details = format_release_details (album);
+    gchar *markup;
 
     if (album->disc_number > 0 && album->disc_count > 1)
       g_string_append_printf (album_title,_(" (Disc %d/%d)"),
                               album->disc_number, album->disc_count);
 
+    markup = g_markup_printf_escaped ("<b>%s</b>\n<i>%s</i>\n%s", album_title->str,
+                                                                  album->artist,
+                                                                  release_details);
+
     gtk_list_store_append (albums_store, &iter);
     gtk_list_store_set (albums_store, &iter,
-                        COLUMN_TITLE, album_title->str,
-                        COLUMN_ARTIST, album->artist,
-                        COLUMN_RELEASE_DETAILS, release_details,
+                        COLUMN_RELEASE, markup,
                         COLUMN_DETAILS, album,
                         -1);
-
+    g_free (markup);
     g_string_free (album_title, TRUE);
     g_free (release_details);
   }
@@ -1850,10 +1880,9 @@ G_MODULE_EXPORT void on_year_edit_changed(GtkEditable *widget, gpointer user_dat
   year = atoi (yearstr);
   if (year > 0) {
     if (current_album->release_date) {
-      g_date_set_dmy (current_album->release_date, 1, 1, year);
-    } else {
-      current_album->release_date = g_date_new_dmy (1, 1, year);
+      gst_date_time_unref (current_album->release_date);
     }
+    current_album->release_date = gst_date_time_new_y (year);
   }
 }
 
