@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors: Ross Burton <ross@burtonini.com>
  */
@@ -29,19 +28,17 @@
 #include <string.h>
 #include <gst/pbutils/encoding-profile.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 #include <brasero-drive-selection.h>
 
 #include "rb-gst-media-types.h"
 #include "sj-util.h"
-#include "gconf-bridge.h"
 #include "sj-extracting.h"
 #include "sj-prefs.h"
 
 extern GtkBuilder *builder;
 extern GtkWidget *main_window;
 
-static GtkWidget *audio_profile;
+static GtkWidget *profile_option;
 static GtkWidget *cd_option, *path_option, *file_option, *basepath_fcb, *check_strip, *check_eject, *check_open;
 static GtkWidget *path_example_label;
 
@@ -60,6 +57,10 @@ static const FilePattern path_patterns[] = {
   {N_("Album Artist (sortable)"), "%as"},
   {N_("Album Artist - Album Title"), "%aa - %at"},
   {N_("Album Artist (sortable) - Album Title"), "%as - %at"},
+  {N_("Album Composer, Album Title"), "%ac/%at"},
+  {N_("Album Composer (sortable), Album Title"), "%ap/%at"},
+  {N_("Track Composer, Album Title"), "%tc/%at"},
+  {N_("Track Composer (sortable), Album Title"), "%tp/%at"},
   {N_("[none]"), "./"},
   {NULL, NULL}
 };
@@ -73,9 +74,25 @@ static const FilePattern file_patterns[] = {
   /* {N_("Number. Track Artist (sortable) - Track Title"), "%tN. %ts - %tt"}, */
   {N_("Number-Track Artist-Track Title (lowercase)"), "%dN-%tA-%tT"},
   /* {N_("Number-Track Artist (sortable)-Track Title (lowercase)"), "%tN-%tS-%tT"}, */
+  {N_("Track Composer - Track Artist - Track Title"), "%tc - %ta - %tt"},
+  {N_("Track Composer (sortable) - Track Artist (sortable) - Track Title"), "%tp - %ts - %tt"},
+  {N_("Number. Track Composer - Track Artist - Track Title"), "%dN. %tc - %ta - %tt"},
+  {N_("Number-Track Composer-Track Artist-Track Title (lowercase)"), "%dN-%tC-%tA-%tT"},
   {NULL, NULL}
 };
 
+const gchar*
+sj_get_default_file_pattern (void)
+{
+  return file_patterns[0].pattern;
+}
+
+const gchar*
+sj_get_default_path_pattern (void)
+{
+  return path_patterns[0].pattern;
+}
+
 void prefs_profile_changed (GtkWidget *widget, gpointer user_data)
 {
   GtkTreeIter iter;
@@ -87,8 +104,7 @@ void prefs_profile_changed (GtkWidget *widget, gpointer user_data)
     char *media_type;
     gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
                         0, &media_type, -1);
-    gconf_client_set_string (gconf_client, GCONF_AUDIO_PROFILE_MEDIA_TYPE,
-                             media_type, NULL);
+    g_settings_set_string (sj_settings, SJ_SETTINGS_AUDIO_PROFILE, media_type);
     g_free (media_type);
   }
 }
@@ -100,7 +116,7 @@ void show_help (GtkWindow *parent)
 {
   GError *error = NULL;
 
-  gtk_show_uri (NULL, "ghelp:sound-juicer?preferences", GDK_CURRENT_TIME, &error);
+  gtk_show_uri (NULL, "help:sound-juicer/preferences", GDK_CURRENT_TIME, &error);
   if (error) {
     GtkWidget *dialog;
 
@@ -126,11 +142,11 @@ G_MODULE_EXPORT void prefs_base_folder_changed (GtkWidget *chooser, gpointer use
 {
   char *new_uri, *current_uri;
 
-  current_uri = gconf_client_get_string (gconf_client, GCONF_BASEURI, NULL);
+  current_uri = g_settings_get_string (sj_settings, SJ_SETTINGS_BASEURI);
   new_uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser));
 
   if (current_uri == NULL || strcmp(current_uri, new_uri) != 0) {
-      gconf_client_set_string (gconf_client, GCONF_BASEURI, new_uri, NULL);
+      g_settings_set_string (sj_settings, SJ_SETTINGS_BASEURI, new_uri);
   }
 
   g_free (new_uri);
@@ -147,7 +163,7 @@ void prefs_path_option_changed (GtkComboBox *combo, gpointer user_data)
 
   pattern = path_patterns[active].pattern;
   if (pattern) {
-    gconf_client_set_string (gconf_client, GCONF_PATH_PATTERN, pattern, NULL);
+    g_settings_set_string (sj_settings, SJ_SETTINGS_PATH_PATTERN, pattern);
   }
 }
 
@@ -161,12 +177,12 @@ G_MODULE_EXPORT void prefs_file_option_changed (GtkComboBox *combo, gpointer use
 
   pattern = file_patterns[active].pattern;
   if (pattern) {
-    gconf_client_set_string (gconf_client, GCONF_FILE_PATTERN, pattern, NULL);
+    g_settings_set_string (sj_settings, SJ_SETTINGS_FILE_PATTERN, pattern);
   }
 }
 
 static void
-sj_audio_profile_chooser_set_active (GtkWidget *chooser, const char *profile)
+sj_profile_option_set_active (GtkWidget *chooser, const char *profile)
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
@@ -192,17 +208,16 @@ sj_audio_profile_chooser_set_active (GtkWidget *chooser, const char *profile)
   }
 }
 
-static void audio_profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+static void audio_profile_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
-  const char *value;
-  g_return_if_fail (strcmp (entry->key, GCONF_AUDIO_PROFILE_MEDIA_TYPE) == 0);
-  if (!entry->value) return;
-  value = gconf_value_get_string (entry->value);
-
-  sj_audio_profile_chooser_set_active (audio_profile, value);
+  char *value;
+  g_return_if_fail (strcmp (key, SJ_SETTINGS_AUDIO_PROFILE) == 0);
+  value = g_settings_get_string (settings, key);
+  sj_profile_option_set_active (profile_option, value);
+  g_free (value);
 }
 
-static void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+static void baseuri_changed_cb  (GSettings *settings, gchar *key, gpointer user_data)
 {
   /*
    * The conflict between separation of the prefs and the main window,
@@ -212,11 +227,9 @@ static void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *
    * into sj-utils?
    */
   const char* base_uri, *current_uri;
-  g_return_if_fail (strcmp (entry->key, GCONF_BASEURI) == 0);
+  g_return_if_fail (strcmp (key, SJ_SETTINGS_BASEURI) == 0);
 
-  base_uri = NULL;
-  if (entry->value != NULL)
-    base_uri = gconf_value_get_string (entry->value);
+  base_uri = g_settings_get_string (settings, key);
 
   if (base_uri == NULL || base_uri[0] == '\0') {
     GFile *dir;
@@ -228,7 +241,6 @@ static void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *
     g_free (dir_uri);
     g_object_unref (dir);
   } else {
-    g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
     current_uri = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (basepath_fcb));
     if (current_uri == NULL || strcmp (current_uri, base_uri) != 0)
       gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (basepath_fcb), base_uri);
@@ -277,13 +289,13 @@ static void pattern_label_update (void)
   gst_encoding_profile_unref (profile);
 
   /* TODO: sucky. Replace with get-gconf-key-with-default mojo */
-  file_pattern = gconf_client_get_string (gconf_client, GCONF_FILE_PATTERN, NULL);
+  file_pattern = g_settings_get_string (sj_settings, SJ_SETTINGS_FILE_PATTERN);
   if (file_pattern == NULL) {
-    file_pattern = g_strdup(file_patterns[0].pattern);
+    file_pattern = g_strdup (sj_get_default_file_pattern ());
   }
-  path_pattern = gconf_client_get_string (gconf_client, GCONF_PATH_PATTERN, NULL);
+  path_pattern = g_settings_get_string (sj_settings, SJ_SETTINGS_PATH_PATTERN);
   if (path_pattern == NULL) {
-    path_pattern = g_strdup(path_patterns[0].pattern);
+    path_pattern = g_strdup (sj_get_default_path_pattern ());
   }
 
   file_value = filepath_parse_pattern (file_pattern, &sample_track);
@@ -309,18 +321,13 @@ static void pattern_label_update (void)
   g_free (format);
 }
 
-static void path_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+static void path_pattern_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
   char *value;
   int i = 0;
-  g_return_if_fail (strcmp (entry->key, GCONF_PATH_PATTERN) == 0);
+  g_return_if_fail (strcmp (key, SJ_SETTINGS_PATH_PATTERN) == 0);
 
-  if (entry->value == NULL) {
-    value = g_strdup (path_patterns[0].pattern);
-  } else if (entry->value->type == GCONF_VALUE_STRING) {
-    value = g_strdup (gconf_value_get_string (entry->value));
-  } else
-    return;
+  value = g_settings_get_string (settings, key);
   while (path_patterns[i].pattern && strcmp(path_patterns[i].pattern, value) != 0) {
     i++;
   }
@@ -329,19 +336,15 @@ static void path_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
   pattern_label_update ();
 }
 
-static void file_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+static void file_pattern_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
   char *value;
   int i = 0;
 
-  g_return_if_fail (strcmp (entry->key, GCONF_FILE_PATTERN) == 0);
+  g_return_if_fail (strcmp (key, SJ_SETTINGS_FILE_PATTERN) == 0);
+
+  value = g_settings_get_string (settings, key);
 
-  if (entry->value == NULL) {
-    value = g_strdup (file_patterns[0].pattern);
-  } else if (entry->value->type == GCONF_VALUE_STRING) {
-    value = g_strdup (gconf_value_get_string (entry->value));
-  } else
-    return;
   while (file_patterns[i].pattern && strcmp(file_patterns[i].pattern, value) != 0) {
     i++;
   }
@@ -351,50 +354,51 @@ static void file_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
 }
 
 /**
- * Default device changed (either GConf key or the widget)
+ * Default device changed (either GSettings key or the widget)
  */
-static void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+static void device_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
-  g_return_if_fail (strcmp (entry->key, GCONF_DEVICE) == 0);
+  BraseroDrive *drive;
+  BraseroMediumMonitor *monitor;
+  char *value;
 
-  if (entry->value == NULL)
-    return;
-
-  if (entry->value->type == GCONF_VALUE_STRING) {
-    BraseroDrive *drive;
-    BraseroMediumMonitor *monitor;
+  g_return_if_fail (strcmp (key, SJ_SETTINGS_DEVICE) == 0);
 
+  value = g_settings_get_string (settings, key);
+  if ((value != NULL) && (*value != '\0')) {
     monitor = brasero_medium_monitor_get_default ();
-    drive = brasero_medium_monitor_get_drive (monitor, gconf_value_get_string (entry->value));
+    drive = brasero_medium_monitor_get_drive (monitor, value);
     brasero_drive_selection_set_active (BRASERO_DRIVE_SELECTION (cd_option), drive);
     g_object_unref (drive);
     g_object_unref (monitor);
+  } else {
+    /* FIXME: see the FIXME in sj-main.c around one of the
+     * device_changed_cb calls for a way to fix this
+     */
+    g_warn_if_reached();
   }
+  g_free (value);
 }
 
 static void prefs_drive_changed (BraseroDriveSelection *selection, BraseroDrive *drive, gpointer user_data)
 {
   if (drive)
-    gconf_client_set_string (gconf_client, GCONF_DEVICE, brasero_drive_get_device (drive), NULL);
+    g_settings_set_string (sj_settings, SJ_SETTINGS_DEVICE, brasero_drive_get_device (drive));
   else
-    gconf_client_set_string (gconf_client, GCONF_DEVICE, NULL, NULL);
+    g_settings_set_string (sj_settings, SJ_SETTINGS_DEVICE, NULL);
 }
 
 /**
- * The GConf key for the strip characters option changed
+ * The GSettings key for the strip characters option changed
  */
-static void strip_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+static void strip_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
   /* NOTE that strip_changed_cb in sj-main.c will also be called, and will also update
      the global value strip_chars - but which function will get called first?
      Make sure strip_chars is up to date BEFORE calling pattern_label_update */
-  g_return_if_fail (strcmp (entry->key, GCONF_STRIP) == 0);
+  g_return_if_fail (strcmp (key, SJ_SETTINGS_STRIP) == 0);
 
-  if (entry->value == NULL) {
-    strip_chars = FALSE;
-  } else {
-    strip_chars = gconf_value_get_bool (entry->value);
-  }
+  strip_chars = g_settings_get_boolean (settings, key);
   pattern_label_update ();
 }
 
@@ -425,12 +429,10 @@ on_response (GtkDialog *dialog, gint response, gpointer user_data)
   }
 }
 
-static GtkWidget *sj_audio_profile_chooser_new(void)
+static void populate_profile_combo (GtkComboBox *combo)
 {
   GstEncodingTarget *target;
   const GList *p;
-  GtkWidget *combo_box;
-  GtkCellRenderer *renderer;
   GtkTreeModel *model;
 
   model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER));
@@ -452,18 +454,13 @@ static GtkWidget *sj_audio_profile_chooser_new(void)
     g_free (media_type);
   }
 
-  combo_box = gtk_combo_box_new_with_model (model);
-  renderer = gtk_cell_renderer_text_new ();
-  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), renderer, TRUE);
-  gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), renderer, "text", 1, NULL);
-
-  return GTK_WIDGET (combo_box);
+  gtk_combo_box_set_model (GTK_COMBO_BOX (combo), model);
 }
 
 /**
  * Clicked on Preferences in the UI
  */
-G_MODULE_EXPORT void on_edit_preferences_cb (GtkMenuItem *item, gpointer user_data)
+void show_preferences_dialog ()
 {
   static GtkWidget *prefs_dialog = NULL;
 
@@ -473,11 +470,8 @@ G_MODULE_EXPORT void on_edit_preferences_cb (GtkMenuItem *item, gpointer user_da
     const char *labels[] = { "cd_label", "path_label", "folder_label", "file_label", "profile_label" };
     guint i;
     GtkSizeGroup *group;
-    GtkWidget    *box;
-    GConfBridge *bridge = gconf_bridge_get ();
 
     prefs_dialog = GET_WIDGET ("prefs_dialog");
-    box          = GET_WIDGET ("hack_hbox");
     g_assert (prefs_dialog != NULL);
     g_object_add_weak_pointer (G_OBJECT (prefs_dialog), (gpointer)&prefs_dialog);
 
@@ -499,19 +493,7 @@ G_MODULE_EXPORT void on_edit_preferences_cb (GtkMenuItem *item, gpointer user_da
     basepath_fcb       = GET_WIDGET ("path_chooser");
     path_option        = GET_WIDGET ("path_option");
     file_option        = GET_WIDGET ("file_option");
-#if 0
-    /* FIXME: This cannot be currently used, because aufio profile selector
-     * 	      from gnome-media-profiles package is not fully qualified widget.
-     * 	      Once gnome-media package is updated, this widget can be created
-     * 	      using GtkBuilder. */
-    audio_profile      = GET_WIDGET ("audio_profile");
-#else
-    audio_profile = sj_audio_profile_chooser_new();
-    g_signal_connect (G_OBJECT (audio_profile), "changed",
-                      G_CALLBACK (prefs_profile_changed), NULL);
-    gtk_box_pack_start (GTK_BOX (box), audio_profile, TRUE, TRUE, 0);
-    gtk_widget_show (audio_profile);
-#endif
+    profile_option     = GET_WIDGET ("profile_option");
     check_strip        = GET_WIDGET ("check_strip");
     check_eject        = GET_WIDGET ("check_eject");
     check_open         = GET_WIDGET ("check_open");
@@ -522,27 +504,35 @@ G_MODULE_EXPORT void on_edit_preferences_cb (GtkMenuItem *item, gpointer user_da
     g_signal_connect (path_option, "changed", G_CALLBACK (prefs_path_option_changed), NULL);
     populate_pattern_combo (GTK_COMBO_BOX (file_option), file_patterns);
     g_signal_connect (file_option, "changed", G_CALLBACK (prefs_file_option_changed), NULL);
+    populate_profile_combo (GTK_COMBO_BOX (profile_option));
+    g_signal_connect (profile_option, "changed", G_CALLBACK (prefs_profile_changed), NULL);
 
     g_signal_connect (cd_option, "drive-changed", G_CALLBACK (prefs_drive_changed), NULL);
 
-    /* Connect to GConf to update the UI */
-    gconf_bridge_bind_property (bridge, GCONF_EJECT, G_OBJECT (check_eject), "active");
-    gconf_bridge_bind_property (bridge, GCONF_OPEN, G_OBJECT (check_open), "active");
-    gconf_bridge_bind_property (bridge, GCONF_STRIP, G_OBJECT (check_strip), "active");
-    gconf_client_notify_add (gconf_client, GCONF_DEVICE, device_changed_cb, NULL, NULL, NULL);
-    gconf_client_notify_add (gconf_client, GCONF_BASEURI, baseuri_changed_cb, NULL, NULL, NULL);
-    gconf_client_notify_add (gconf_client, GCONF_AUDIO_PROFILE_MEDIA_TYPE, audio_profile_changed_cb, NULL, NULL, NULL);
-    gconf_client_notify_add (gconf_client, GCONF_PATH_PATTERN, path_pattern_changed_cb, NULL, NULL, NULL);
-    gconf_client_notify_add (gconf_client, GCONF_FILE_PATTERN, file_pattern_changed_cb, NULL, NULL, NULL);
-    gconf_client_notify_add (gconf_client, GCONF_STRIP, strip_changed_cb, NULL, NULL, NULL);
+    /* Connect to GSettings to update the UI */
+    g_settings_bind (sj_settings, SJ_SETTINGS_EJECT, G_OBJECT (check_eject), "active", G_SETTINGS_BIND_DEFAULT);
+    g_settings_bind (sj_settings, SJ_SETTINGS_OPEN, G_OBJECT (check_open), "active", G_SETTINGS_BIND_DEFAULT);
+    g_settings_bind (sj_settings, SJ_SETTINGS_STRIP, G_OBJECT (check_strip), "active", G_SETTINGS_BIND_DEFAULT);
+    g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_DEVICE,
+                      (GCallback)device_changed_cb, NULL);
+    g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_BASEURI,
+                      (GCallback)baseuri_changed_cb, NULL);
+    g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_AUDIO_PROFILE,
+                      (GCallback)audio_profile_changed_cb, NULL);
+    g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_PATH_PATTERN,
+                      (GCallback)path_pattern_changed_cb, NULL);
+    g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_FILE_PATTERN,
+                      (GCallback)file_pattern_changed_cb, NULL);
+    g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_STRIP,
+                      (GCallback)strip_changed_cb, NULL);
 
     g_signal_connect (extractor, "notify::profile", pattern_label_update, NULL);
 
-    baseuri_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_BASEURI, NULL, TRUE, NULL), NULL);
-    audio_profile_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_AUDIO_PROFILE_MEDIA_TYPE, NULL, TRUE, NULL), NULL);
-    file_pattern_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_FILE_PATTERN, NULL, TRUE, NULL), NULL);
-    path_pattern_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_PATH_PATTERN, NULL, TRUE, NULL), NULL);
-    device_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL), NULL);
+    baseuri_changed_cb (sj_settings, SJ_SETTINGS_BASEURI, NULL);
+    audio_profile_changed_cb (sj_settings, SJ_SETTINGS_AUDIO_PROFILE, NULL);
+    file_pattern_changed_cb (sj_settings, SJ_SETTINGS_FILE_PATTERN, NULL);
+    path_pattern_changed_cb (sj_settings, SJ_SETTINGS_PATH_PATTERN, NULL);
+    device_changed_cb (sj_settings, SJ_SETTINGS_DEVICE, NULL);
 
     g_signal_connect (GTK_DIALOG (prefs_dialog), "response", G_CALLBACK (on_response), NULL);
 
