@@ -59,6 +59,7 @@ metadata_cb (SjMetadataGetter *metadata, GList *albums, const GError *error)
     AlbumDetails *album;
     album = (AlbumDetails*)albums->data;
     char *disc_number;
+    char *release_date;
     g_print ("Source: %s\n", source_to_str(album->metadata_source));
     if (album->metadata_source == SOURCE_MUSICBRAINZ)
       g_print ("Album ID: %s\n", album->album_id);
@@ -71,8 +72,10 @@ metadata_cb (SjMetadataGetter *metadata, GList *albums, const GError *error)
     if (album->is_spoken_word)
       g_print ("Is spoken word\n");
     disc_number = g_strdup_printf (" (Disc %d)", album->disc_number);
-    g_print ("'%s', by %s%s, released %d-%02d-%02d\n", album->title, album->artist, album->disc_number ? disc_number : "",
-             g_date_get_year (album->release_date), g_date_get_month (album->release_date), g_date_get_day (album->release_date));
+    release_date = gst_date_time_to_iso8601_string (album->release_date);
+    g_print ("'%s', by %s%s, released %s\n", album->title, album->artist, album->disc_number ? disc_number : "",
+             release_date);
+    g_free (release_date);
     g_free (disc_number);
     while (album->tracks) {
       TrackDetails *track = (TrackDetails*)album->tracks->data;
